@@ -42,6 +42,7 @@
   IBOutlet NSPopUpButton *popupStrEncoding;
   IBOutlet NSButton      *buttPrefCancel;
   IBOutlet NSButton      *buttPrefOk;
+  IBOutlet NSButton      *buttPrefHttps;
   
   /* login */
   IBOutlet NSWindow      *winLogin;
@@ -73,6 +74,13 @@
   IBOutlet NSTextView    *fieldQuerySelect;
   IBOutlet NSTextField   *fieldFileSelect;
   IBOutlet NSButton      *queryAllSelect;
+
+  /* query identify */
+  IBOutlet NSWindow      *winSelectIdentify;
+  IBOutlet NSTextView    *fieldQuerySelectIdentify;
+  IBOutlet NSTextField   *fieldFileSelectIdentifyIn;
+  IBOutlet NSTextField   *fieldFileSelectIdentifyOut;
+  IBOutlet NSButton      *queryAllSelectIdentify;
   
   /* insert */
   IBOutlet NSWindow      *winInsert;
@@ -131,6 +139,11 @@
 - (IBAction)browseFileSelect:(id)sender;
 - (IBAction)executeSelect:(id)sender;
 
+- (IBAction)showSelectIdentify:(id)sender;
+- (IBAction)browseFileSelectIdentifyIn:(id)sender;
+- (IBAction)browseFileSelectIdentifyOut:(id)sender;
+- (IBAction)executeSelectIdentify:(id)sender;
+
 - (IBAction)showQuickDelete:(id)sender;
 - (IBAction)quickDelete:(id)sender;
 
