@@ -30,7 +30,7 @@
 
 @implementation DBSoap
 
-- (void)login :(NSURL *)url :(NSString *)userName :(NSString *)password
+- (void)login :(NSURL *)url :(NSString *)userName :(NSString *)password :(BOOL)useHttps
 {
   GWSSOAPCoder          *coder;
   NSUserDefaults        *defs;
@@ -154,7 +154,8 @@
   if ([[serverUrl substringToIndex:5] isEqualToString:@"https"])
   {
     NSLog(@"we have https....");
-    serverUrl = [@"http" stringByAppendingString:[serverUrl substringFromIndex:5]];
+    if (!useHttps)
+      serverUrl = [@"http" stringByAppendingString:[serverUrl substringFromIndex:5]];
   }
   
   [coder release];
@@ -514,7 +515,8 @@
       queryLocator = [result objectForKey:@"queryLocator"];
       NSLog(@"should do query more, queryLocator: %@", queryLocator);
     }
-  return queryLocator;}
+  return queryLocator;
+}
 
 
 - (void)query :(NSString *)queryString queryAll:(BOOL)all toWriter:(DBCVSWriter *)writer
@@ -584,10 +586,105 @@
           [set addObject:values];
         }
       [writer writeDataSet:set];
-      [set release];
-      
-    }}
+      [set release];      
+    }
+  [sObjects release];
+}
 
+- (void)queryIdentify :(NSString *)queryString queryAll:(BOOL)all fromReader:(DBCVSReader *)reader toWriter:(DBCVSWriter *)writer 
+{
+  NSArray *inFieldNames;
+  unsigned inFieldCount;
+  NSArray *dataSet;
+  NSMutableArray *identifierArray;
+  NSMutableArray *sObjects;
+  NSString *identifier;
+  unsigned i;
+  unsigned j;
+  unsigned batchSize;
+  NSArray *keys;
+
+  /* retrieve objects to create */
+  NSLog(@"CVS identify 1.....");
+  
+  /* first the fields */
+  inFieldNames = [reader fieldNames];
+  inFieldCount = [inFieldNames count];
+  dataSet = [reader readDataSet];
+  NSLog(@"field names: %@", inFieldNames);
+  if (inFieldCount > 1)
+    {
+      NSLog(@"We cannot identify %d field", inFieldCount);
+      return;
+    }
+  identifierArray = [[NSMutableArray arrayWithCapacity: [dataSet count]] retain];
+  for (i = 0; i < [dataSet count]; i++)
+    [identifierArray addObject: [[dataSet objectAtIndex: i] objectAtIndex: 0]];
+  sObjects = [[NSMutableArray alloc] init];
+  identifier = [inFieldNames objectAtIndex: 0];
+  NSLog(@"identify through %@", identifier);
+
+  [self queryIdentify:queryString with:identifier queryAll:all fromArray:identifierArray toArray: sObjects];
+
+  keys = nil;
+  batchSize = [sObjects count];
+  if (batchSize > 0)
+    {
+      DBSObject *obj;
+      NSMutableArray *set;
+
+      obj = [sObjects objectAtIndex: 0];
+      keys = [obj fieldNames];
+      [writer setFieldNames:keys andWriteIt:YES];
+
+      set = [[NSMutableArray alloc] init];
+      for (i = 0; i < batchSize; i++)
+        {
+          NSMutableArray *values;
+	  DBSObject *record;
+	  
+          record = [sObjects objectAtIndex:i];
+          values = [NSMutableArray arrayWithCapacity:[keys count]];
+          for (j = 0; j < [keys count]; j++)
+            {
+              [values addObject:[record fieldValue: [keys objectAtIndex:j]]];
+            }
+          [set addObject:values];
+        }
+      [writer writeDataSet:set];
+      [set release];
+    }
+
+  [sObjects release];
+  [identifierArray release];
+}
+
+- (void)queryIdentify :(NSString *)queryString with: (NSString *)identifier queryAll:(BOOL)all fromArray:(NSArray *)fromArray toArray:(NSMutableArray *)outArray 
+{
+  unsigned i;
+  NSMutableArray *resArray;
+
+  resArray = [[NSMutableArray arrayWithCapacity: 1] retain];
+  for (i = 0; i < [fromArray count]; i++)
+    {
+      NSMutableString *completeQuery;
+
+      NSLog(@"%u %@", i, [fromArray objectAtIndex: i]);
+      [resArray removeAllObjects];
+      completeQuery = [[NSMutableString stringWithString: queryString] retain];
+      [completeQuery appendString: @" Where "];
+      [completeQuery appendString: identifier];
+      [completeQuery appendString: @" = '"];
+      [completeQuery appendString: [fromArray objectAtIndex: i]];
+      [completeQuery appendString: @"'"];
+      NSLog(@"query: %@", completeQuery);
+
+      [self query:completeQuery queryAll:all toArray:resArray];
+      [outArray addObject: [resArray objectAtIndex: 0]];
+      [completeQuery release];
+    }
+  [resArray release];
+}
 
 
 - (void)create :(NSString *)objectName fromReader:(DBCVSReader *)reader
@@ -659,7 +756,7 @@
 
     for (i = 0; i < fieldCount; i++)
       {
-        NSLog(@"%@: %@ - %@", objectName, [fieldNames objectAtIndex:i], [fieldValues objectAtIndex:i]);
+	//        NSLog(@"%@: %@ - %@", objectName, [fieldNames objectAtIndex:i], [fieldValues objectAtIndex:i]);
         [sObj setObject: [fieldValues objectAtIndex:i] forKey: [fieldNames objectAtIndex:i]];
         [sObjKeyOrder addObject:[fieldNames objectAtIndex:i]];
       }
@@ -759,7 +856,8 @@
         }
       /* we don't do yet anything useful with the results... */
       [set release];
-    }}
+    }
+}
 
 
 - (void)update :(NSString *)objectName fromReader:(DBCVSReader *)reader
@@ -932,7 +1030,8 @@
       }
       /* we don't do yet anything useful with the results... */
       [set release];
-    }}
+    }
+}
 
 
 
